# Hello Colloquium

This is the broad feature tour deck.

Use it when you want one example that touches most of the default authoring surface:

- math
- code highlighting
- columns
- centered content
- charts
- citations
- conversation blocks
- box callouts
- footnotes
